@@ -13,15 +13,16 @@ use warnings;
 
 package Pod::Markdown;
 {
-  $Pod::Markdown::VERSION = '1.400';
+  $Pod::Markdown::VERSION = '1.401';
 }
-# git description: v1.322-20-g5d0671c
+# git description: v1.400-1-ge7a28a2
 
 BEGIN {
   $Pod::Markdown::AUTHORITY = 'cpan:RWSTAUNER';
 }
 # ABSTRACT: Convert POD to Markdown
 
+use Pod::Parser 1.51 ();
 use parent qw(Pod::Parser);
 use Pod::ParseLink (); # core
 
@@ -236,9 +237,18 @@ sub verbatim {
         $paragraph = join "\n", map { /^\t/ ? $_ : $indent . $_ } @lines;
     }
 
-    if($parser->{_PREVIOUS} eq 'verbatim' && $parser->_private->{Text}->[-1] =~ /[ \t]+$/) {
+    # FIXME: Checking _PREVIOUS is breaking Pod::Parser encapsulation
+    # but helps solve the extraneous extra blank line b/t verbatim blocks.
+    # We could probably keep track ourselves if need be.
+    # NOTE: This requires Pod::Parser 1.50.
+    # This is another reason to switch to Pod::Simple.
+    my $previous_was_verbatim =
+        $parser->{_PREVIOUS} && $parser->{_PREVIOUS} eq 'verbatim';
+
+    if($previous_was_verbatim && $parser->_private->{Text}->[-1] =~ /[ \t]+$/){
         $paragraph = $parser->_unsave . "\n" . $paragraph;
     }
+
     $parser->_save($paragraph);
 }
 
@@ -418,7 +428,7 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 1.400
+version 1.401
 
 =head1 SYNOPSIS
 
